pub fn crystallization_tendency(
_chain: &PolymerChain,
) -> CrystallizationTendencyExpand description
Estimates the crystallisation tendency of a polymer chain based on its structural regularity and symmetry.
pub fn crystallization_tendency(
_chain: &PolymerChain,
) -> CrystallizationTendencyEstimates the crystallisation tendency of a polymer chain based on its structural regularity and symmetry.